@@ -278,7 +278,13 @@
 #include "token_info-5.27.0.h"
 #elif PERL_VERSION == 27 && PERL_SUBVERSION == 6
 #include "token_info-5.27.0.h"
-#elif PERL_VERSION > 27 || (PERL_VERSION == 27 && PERL_SUBVERSION > 6)
+#elif PERL_VERSION == 27 && PERL_SUBVERSION == 7
+#include "token_info-5.27.7.h"
+#elif PERL_VERSION == 27 && PERL_SUBVERSION == 8
+#include "token_info-5.27.8.h"
+#elif PERL_VERSION == 27 && PERL_SUBVERSION == 9
+#include "token_info-5.27.8.h"
+#elif PERL_VERSION > 27 || (PERL_VERSION == 27 && PERL_SUBVERSION > 9)
 #include "token_info-latest.h"
 #else
 #error "No support for this perl version"
